@@ -5,6 +5,7 @@ module for reading in stream
 
 from dataclasses import dataclass
 import glob
+from pathlib import Path
 import subprocess as sp
 import time
 
@@ -62,7 +63,50 @@ class LiveStreamer(_Streamer):
             else:
                 self._error_frames += 1
                 if self._error_frames >= self._max_errors:
-                    raise StopIteration("# of error is greater than allowed. stop stream")
+                    self._error_frames = 0
+                    raise StopIteration(f"# of error {self._error_frames} "
+                                        f"is greater than allowed. stop stream")
+        raise ValueError(f"<{self._stream}> is closed. please reconnect")
+
+    def __del__(self):
+        self._stream.release()
+
+
+class VideoFileStreamer(_Streamer):
+    """
+    class for read from a video file
+    """
+
+    def __init__(self, source, rate: float = 1):
+        super().__init__(source, rate)
+        self._stream = cv2.VideoCapture(self.source)
+        self._fps = self._stream.get(cv2.CAP_PROP_FPS)
+        self._gap = int(self._fps / rate)
+        self._count = 0
+        self._index = 0
+
+    @property
+    def fps(self) -> int:
+        """
+        get stream fps
+        :return:
+        """
+        return self._fps
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        while True:
+            ret, frame = self._stream.read()
+            if ret:
+                self._count += 1
+                if self._count >= self._gap:
+                    self._count = 0
+                    self._index += 1
+                    return frame, self._index
+            else:
+                raise StopIteration
 
     def __del__(self):
         self._stream.release()
@@ -75,7 +119,7 @@ class ImageFileStreamer(_Streamer):
 
     def __init__(self, source, suffix: str = 'jpg', rate: int = 1):
         super().__init__(source, rate)
-        self._stream = glob.glob((self._source / ("**" + suffix)).as_posix(), recursive=True)
+        self._stream = glob.glob((Path(self.source) / ("**" + suffix)).as_posix(), recursive=True)
         self._stream = sorted(self._stream, key=lambda x: (len(x), x))
         self._rate = rate
         self._start = 0
@@ -93,31 +137,6 @@ class ImageFileStreamer(_Streamer):
         return img, file_loc
 
 
-class VideoFileStreamer(_Streamer):
-    """
-    class for read frame from a video file
-    """
-
-    def __init__(self, source: str, rate: int = 1):
-        super().__init__(source, rate)
-        self._rate = rate
-        self._stream = cv2.VideoCapture(self.source)
-        self._start = 0
-
-    def __iter__(self):
-        return self
-
-    def __next__(self):
-        while True:
-            ret, img = self._stream.read()
-            if not ret:
-                raise StopIteration
-
-            self._start += 1
-            if self._start % self._rate == 0:
-                return img, None
-
-
 class LivePusher:
     """
     class for live stream writer
