@@ -24,10 +24,16 @@ from sail_utils.cv.head.protobuf import (
 )
 
 
-def _unary_detect(stub, img, time_out=None):
+def _unary_detect(stub, img, time_out=None, **kwargs):
+
+    if 'model_version' in kwargs:
+        model_version = kwargs['model_version']
+    else:
+        model_version = 0
+
     request = inference_head_detection_pb2. \
         ObjectDetectionRequest(request_info=__name__,
-                               model_version=0)
+                               model_version=model_version)
     img_encode = cv2.imencode('.jpg', img)[1]
     request.image_data = img_encode.tobytes()
     response_f = stub.DetectHead.future(request)
@@ -74,7 +80,7 @@ class HeadDetector(_Detector):
                  timeout: float = DEFAULT_TIME_OUT):
         super().__init__(server, src_size, dst_size, threshold, timeout)
 
-    def detect(self, img: np.ndarray, epoch) -> list:
+    def detect(self, img: np.ndarray, epoch, **kwargs) -> list:
         """
         detect on one image
         :param img:
@@ -84,5 +90,5 @@ class HeadDetector(_Detector):
         img = self._mapper.resize(img)
         with grpc.insecure_channel(self._server) as channel:
             stub = inference_head_detection_pb2_grpc.HeadDetectionStub(channel)
-            resp = _unary_detect(stub, img, self._timeout)
+            resp = _unary_detect(stub, img, self._timeout, **kwargs)
             return _format(resp, epoch, self._threshold, self._mapper)
