@@ -5,12 +5,10 @@ module for merging video files
 
 from pathlib import Path
 
-from lockfile import LockFile
 from simpleutils.time import unix2dt
-from ffmpy import FFmpeg
 
-from sail_utils import LOGGER
 from sail_utils.oss.utilities import OSSUtility
+from sail_utils.utilities import _merge
 
 
 class Merger:
@@ -80,7 +78,8 @@ class Merger:
                 file_start_epoch = int(file_start_epoch)
                 file_end_epoch = int(file_end_epoch)
                 if start_epoch <= file_start_epoch <= end_epoch \
-                        or start_epoch <= file_end_epoch <= end_epoch:
+                        or start_epoch <= file_end_epoch <= end_epoch \
+                        or (file_start_epoch <= start_epoch and end_epoch <= file_end_epoch):
                     download_file = download_folder / file_name
                     self.oss_utils.download(file, download_file)
                     used_files.append(download_file)
@@ -104,18 +103,5 @@ class Merger:
 
         if used_files:
             # merge
-            file_list_name = Path(f"tmp/{start_epoch}_{end_epoch}.txt")
-            with LockFile(file_list_name.as_posix() + '.lock'):
-                if not file_list_name.exists():
-                    with open(file_list_name, 'w') as f_handle:
-                        for file in used_files:
-                            f_handle.write(f"file '{file.name}'\n")
-                else:
-                    LOGGER.info(f'<{file_list_name}> already exists.')
-
-            ff_cmd = FFmpeg(global_options=['-f', 'concat'],
-                            inputs={file_list_name.as_posix(): ['-safe', '0']},
-                            outputs={merged_file: ['-c', 'copy']})
-            LOGGER.info(ff_cmd.cmd)
-            ff_cmd.run()
+            _merge(start_epoch, end_epoch, merged_file, used_files)
         return merged_file
